##  Managing User Access and Permissions
Once you've configured basic workspace settings, you can start inviting users. To streamline the process of user access management, consider setting up single sign-on (SSO) for your organization. This will allow users to access the workspace from your SSO identity provider, enhancing security and convenience. To learn how to manage user access with and without SSO, see [Managing Users](https://help.sap.com/docs/leanix/ea/managing-users?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to manage user access and roles with and without single sign-on \(SSO\).").
You can manage fact sheet permissions for non-admin user roles in the Meta Model Configuration section of the administration area. Additionally, you can configure role-based permissions that are not related to fact sheets in the User Roles and Permissions section of the administration area. For more details, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
If needed, you can set up virtual workspaces to limit access to specific inventory data. For more information, see [Virtual Workspaces](https://help.sap.com/docs/leanix/ea/virtual-workspaces?locale=en-US&state=PRODUCTION&version=CLOUD "Manage access to fact sheets for custom user groups").
